@@ -19,13 +19,15 @@ public:
 
     void setImageSize( int w, int h );
 
-    void addImage( const char* upperText,
-                   const char* lowerText,
+    void addImage( const std::string upperText,
+                   const std::string lowerText,
                    CL_Surface* image,
                    bool autoResize=true );
 
     void setCurrentImage( int index ) {
         currentImage = newImage = index;
+        CAImageView::image.upperText = image[newImage].upperText;
+        CAImageView::image.lowerText = image[newImage].lowerText;
     }
     int  getSelectedImage() {
         return newImage;
@@ -36,7 +38,6 @@ public:
 
 private:
     //! Pointer to surfaces which can be selected
-
     CAImageData image[CA_IV_MAXIMAGES];
     //! Number of surfaces
     int numImages;
